@@ -12,14 +12,6 @@ from near_api.signer import Signer, KeyPair
 
 from loozr_near_sdk.utils.constants import ACCOUNT_INIT_BALANCE
 
-LZR_CREATOR_MIXER_SECRET_KEY = os.environ.get('MIXER_SECRET_KEY')
-LZR_CREATOR_MIXER_ACCOUNT_ID = os.environ.get(
-    'MIXER_ACCOUNT_ID', default='lzr-mixer.testnet')
-
-
-def get_creator_account_id_from_name(account_name):
-    return "%s.%s" % (account_name, LZR_CREATOR_MIXER_ACCOUNT_ID)
-
 
 class AccountHelper():
     def __init__(self, account_provider=None) -> None:
